@@ -2,7 +2,7 @@
  * This file is part of signon
  *
  * Copyright (C) 2009-2010 Nokia Corporation.
- * Copyright (C) 2013 Canonical Ltd.
+ * Copyright (C) 2013-2015 Canonical Ltd.
  *
  * Contact: Aurel Popirtac <ext-aurel.popirtac@nokia.com>
  * Contact: Alberto Mardegan <alberto.mardegan@canonical.com>
@@ -386,10 +386,6 @@ void SignonDaemon::init()
 
     m_configuration->load();
 
-    if (getuid() != 0) {
-        BLAME() << "Failed to SUID root. Secure storage will not be available.";
-    }
-
     QCoreApplication *app = QCoreApplication::instance();
     if (!app)
         qFatal("SignonDaemon requires a QCoreApplication instance to be "
