@@ -705,8 +705,12 @@ void SignonSessionCore::processUiRequest(const QVariantMap &data)
         request.m_params[SSOUI_KEY_CLIENT_DATA] = m_clientData;
         request.m_params[SSOUI_KEY_METHOD] = m_method;
         request.m_params[SSOUI_KEY_MECHANISM] = request.m_mechanism;
-        request.m_params[SSOUI_KEY_PID] =
-            AccessControlManagerHelper::instance()->pidOfPeer(request.m_conn,
+        /* Pass some data about the requesting client */
+        AccessControlManagerHelper *acm =
+            AccessControlManagerHelper::instance();
+        request.m_params[SSOUI_KEY_PID] = acm->pidOfPeer(request.m_conn,
+                                                         request.m_msg);
+        request.m_params[SSOUI_KEY_APP_ID] = acm->appIdOfPeer(request.m_conn,
                                                               request.m_msg);
 
         CredentialsAccessManager *camManager =
